/*
-------------------------------------------------------------------------------
    This file is a part of the Vst Preset Generator
    Copyright (C) 2007  Francois Mazen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-------------------------------------------------------------------------------
  Name: vpglanguagechooser.cpp
  Author: Francois Mazen
  Date: 28/05/07 16:25
  Description: a simple dialog to choose the language of the software
-------------------------------------------------------------------------------
*/

#include <QtGui>


#include "vpglanguagechooser.h"


//-----------------------------------------------------------------------------
VpgLanguageChooser::VpgLanguageChooser(QWidget *parent)
     : QDialog(parent)
 {

     languageLabel = new QLabel(tr("Please choose your language:"),this);
     cbLanguage = new QComboBox(this);
     qmFiles = findQmFiles();

     for (int i = 0; i < qmFiles.size(); ++i) {

         qmFileMap.insert(languageName(qmFiles[i]),qmFiles[i]);
         cbLanguage->addItem(languageName(qmFiles[i]));
     }


     buttonBox = new QDialogButtonBox;

     btnOk = buttonBox->addButton(tr("&Ok"), QDialogButtonBox::ActionRole);
     btnCancel = buttonBox->addButton(tr("&Cancel"), QDialogButtonBox::ActionRole);

     connect(btnOk, SIGNAL(clicked()), this, SLOT(setLanguage()));
     connect(btnCancel, SIGNAL(clicked()), this, SLOT(setCancel()));

     QVBoxLayout *mainLayout = new QVBoxLayout;
     mainLayout->addWidget(languageLabel);
     mainLayout->addWidget(cbLanguage);
     mainLayout->addWidget(buttonBox);
     setLayout(mainLayout);


     setWindowTitle(tr("Language Chooser"));
     this->layout()->setSizeConstraint(QLayout::SetFixedSize);
 }

//-----------------------------------------------------------------------------
 void VpgLanguageChooser::setLanguage()
 {
     //exit
     done(1);
 }

//-----------------------------------------------------------------------------
 void VpgLanguageChooser::setCancel()
 {
     done(0);
 }

//-----------------------------------------------------------------------------
 QStringList VpgLanguageChooser::findQmFiles()
 {
     QDir dir(":/translations");
     QStringList fileNames = dir.entryList(QStringList("*.qm"), QDir::Files,
                                           QDir::Name);
     QMutableStringListIterator i(fileNames);
     while (i.hasNext()) {
         i.next();
         i.setValue(dir.filePath(i.value()));
     }
     return fileNames;
 }

//-----------------------------------------------------------------------------
 QString VpgLanguageChooser::languageName(const QString &qmFile)
 {
     QTranslator translator;
     translator.load(qmFile);

     return translator.translate("MainDialog", "Language");
 }


